<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
  version="1.0"
  xmlns="http://www.w3.org/1999/xhtml"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:winpixel="http://tilde.town/~lucidiot/winpixel/"
  xsi:schemaLocation="http://tilde.town/~lucidiot/winpixel winpixel.xsd">
  <!-- Generates a single HTML page for a gallery -->
  <xsl:output method="html" />

  <xsl:param name="name" select="'index'" />
  
  <xsl:template match="/">
    <html>
      <head>
        <title>
          <xsl:value-of select="$name" />
          <xsl:text> - winpixel</xsl:text>
        </title>
        <link rel="stylesheet" type="text/css" href="../theme.css" />
        <link rel="shortcut icon" type="image/x-icon" href="../../img/favicon.ico" />
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <meta name="author" content="~lucidiot" />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <xsl:element name="meta">
          <xsl:attribute name="name">generator</xsl:attribute>
          <xsl:attribute name="content">
            <xsl:value-of select="system-property('xsl:vendor')" />
          </xsl:attribute>
        </xsl:element>
      </head>
      <body class="container">
        <xsl:choose>
          <xsl:when test="$name = 'index'">
            <h1>winpixel</h1>
          </xsl:when>
          <xsl:otherwise>
            <h1>
            <xsl:value-of select="$name" />
            </h1>
            <p>
              a
              <a href="index.html">winpixel</a>
              gallery
            </p>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="//winpixel:gallery[@name = $name]/*" />
      </body>
    </html>
  </xsl:template>
  
  <xsl:template match="winpixel:artwork">
    <div class="section">
      <a href="#top" class="toplink">back to top</a>
      <xsl:apply-templates />
    </div>
  </xsl:template>

  <xsl:template match="winpixel:section">
    <div class="section">
      <a href="#top" class="toplink">back to top</a>
      <xsl:value-of select="text()" disable-output-escaping="yes" />
    </div>
  </xsl:template>

  <xsl:template match="winpixel:gallery-list">
    <div class="section">
      <a href="#top" class="toplink">back to top</a>
      <h2>galleries</h2>
      <ul>
        <xsl:for-each select="//winpixel:gallery[@name != $name]">
          <li>
            <a href="{@name}.html">
              <xsl:choose>
                <xsl:when test="@title">
                  <xsl:value-of select="@title" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="@name" />
                </xsl:otherwise>
              </xsl:choose>
            </a>
          </li>
        </xsl:for-each>
      </ul>
    </div>
  </xsl:template>
  
  <xsl:template match="winpixel:title">
    <h2><xsl:value-of select="text()" /></h2>
  </xsl:template>

  <xsl:template match="winpixel:description">
    <xsl:value-of select="text()" disable-output-escaping="yes" />
  </xsl:template>

  <!-- Copy the <img>, but as an XHTML element, without the winpixel namespace -->
  <xsl:template match="winpixel:img">
    <xsl:element name="img">
      <xsl:copy-of select="@*" />
    </xsl:element>
  </xsl:template>
</xsl:stylesheet>